@@ -30,16 +30,6 @@ class DiscordBot(MultiBot[Bot]):
     # ----------------------------------------------------------- #
     # -------------------- PROTECTED METHODS -------------------- #
     # ----------------------------------------------------------- #
-    async def _accept_button_event(self, event: constants.DISCORD_EVENT | Message):
-        match event:
-            case Message():
-                event = event.original_event
-
-        try:
-            await event.response.defer()
-        except AttributeError:
-            pass
-
     def _add_handlers(self):
         super()._add_handlers()
         self.client.add_listener(self._on_ready, 'on_ready')
@@ -137,15 +127,26 @@ class DiscordBot(MultiBot[Bot]):
         mentions = OrderedSet(self._create_user_from_discord_user(user) for user in original_message.mentions)
 
         chat = await self._get_chat(original_message)
-        if chat.original_object.guild:
-            text = await self._get_text(original_message)
-            text = flanautils.remove_symbols(text, replace_with=' ')
-            words = text.lower().split()
+        text = await self._get_text(original_message)
+        text = flanautils.remove_symbols(text, ignore=('#',), replace_with=' ')
+        words = text.lower().split()
+
+        if chat.is_group:
             for member in chat.original_object.guild.members:
                 user_name = f'{member.name}#{member.discriminator}'.lower()
                 short_user_name = member.name.lower()
                 if user_name in words or short_user_name in words:
                     mentions.add(self._create_user_from_discord_user(member))
+        else:
+            user_name = f'{chat.original_object.recipient.name}#{chat.original_object.recipient.discriminator}'.lower()
+            short_user_name = chat.original_object.recipient.name.lower()
+            if user_name in words or short_user_name in words:
+                mentions.add(self._create_user_from_discord_user(chat.original_object.recipient))
+
+            bot_name = f'{chat.original_object.me.name}#{chat.original_object.me.discriminator}'.lower()
+            short_bot_name = chat.original_object.me.name.lower()
+            if bot_name in words or short_bot_name in words:
+                mentions.add(self._create_user_from_discord_user(chat.original_object.me))
 
         return list(mentions - None)
 
@@ -248,6 +249,16 @@ class DiscordBot(MultiBot[Bot]):
     # -------------------------------------------------------- #
     # -------------------- PUBLIC METHODS -------------------- #
     # -------------------------------------------------------- #
+    async def accept_button_event(self, event: constants.DISCORD_EVENT | Message):
+        match event:
+            case Message():
+                event = event.original_event
+
+        try:
+            await event.response.defer()
+        except AttributeError:
+            pass
+
     async def add_role(self, user: int | str | User, group_: int | str | Chat | Message, role: int | str | Role):
         user = await self.get_user(user, group_)
         try:
